@@ -17,6 +17,12 @@
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
+# 出价低于当前价格
+FAILEDOPERATION_BIDPREDOMAINSPRICEDOWNERR = 'FailedOperation.BidPreDomainsPriceDownErr'
+
+# 当前已经结束，不在出价时间范围内。
+FAILEDOPERATION_BIDPREDOMAINSTIMEOUTERR = 'FailedOperation.BidPreDomainsTimeOutErr'
+
 # 域名查询失败，请稍后重试该功能。
 FAILEDOPERATION_CHECKDOMAINFAILED = 'FailedOperation.CheckDomainFailed'
 
@@ -77,6 +83,9 @@ FAILEDOPERATION_TEMPLATEMAXNUMFAILED = 'FailedOperation.TemplateMaxNumFailed'
 # 域名提交转入失败，请稍后重试。
 FAILEDOPERATION_TRANSFERINDOMAINFAILED = 'FailedOperation.TransferInDomainFailed'
 
+# 用户不再白名单列表，无法调用该接口
+FAILEDOPERATION_UINNOTWHITELISTERR = 'FailedOperation.UinNotWhiteListErr'
+
 # 上传图片操作失败。
 FAILEDOPERATION_UPLOADIMAGEFAILED = 'FailedOperation.UploadImageFailed'
 
@@ -86,9 +95,39 @@ FAILEDOPERATION_VERIFYUINISREALNAME = 'FailedOperation.VerifyUinIsRealname'
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
+# IP格式错误。
+INTERNALERROR_DNSHOSTIPCHECKERR = 'InternalError.DNSHostIPCheckErr'
+
+# 数据库报错。
+INTERNALERROR_DBERROR = 'InternalError.DbError'
+
+# 查询域名信息失败。
+INTERNALERROR_DESCRIBEDOMAININFOERR = 'InternalError.DescribeDomainInfoErr'
+
+# 未到释放时间，请稍后再试。
+INTERNALERROR_DESCRIBEPREDOMAINLISTNOTBEGIN = 'InternalError.DescribePreDomainListNotBegin'
+
 # 网络报错，请稍后重试。
 INTERNALERROR_DOMAININTERNALERROR = 'InternalError.DomainInternalError'
 
+# 禁止请求。
+INTERNALERROR_FORBIDDENREQUEST = 'InternalError.ForbiddenRequest'
+
+# 转json错误。
+INTERNALERROR_JSONMARSHAL = 'InternalError.JsonMarshal'
+
+# method不匹配。
+INTERNALERROR_METHODNOTMATCH = 'InternalError.MethodNotMatch'
+
+# 修改DNSHost失败。
+INTERNALERROR_MODIFYDNSHOSTERR = 'InternalError.ModifyDNSHostErr'
+
+# 需要登录。
+INTERNALERROR_NEEDLOGIN = 'InternalError.NeedLogin'
+
+# 读取body失败。
+INTERNALERROR_READBODYERROR = 'InternalError.ReadBodyError'
+
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
@@ -107,6 +146,9 @@ INVALIDPARAMETER_CUSTOMDNSNAMENOTFOUND = 'InvalidParameter.CustomDnsNameNotFound
 # 无权限自定义DNS。
 INVALIDPARAMETER_CUSTOMDNSNOTALLOWED = 'InvalidParameter.CustomDnsNotAllowed'
 
+# 域名输入不规范。
+INVALIDPARAMETER_DOMAINISINVALID = 'InvalidParameter.DomainIsInvalid'
+
 # 域名输入为空或者不正确。
 INVALIDPARAMETER_DOMAINNAMEISINVALID = 'InvalidParameter.DomainNameIsInvalid'
 
@@ -179,6 +221,9 @@ INVALIDPARAMETER_VERIFYCODEISINVALID = 'InvalidParameter.VerifyCodeIsInvalid'
 # 邮编为空或者不合法。
 INVALIDPARAMETER_ZIPCODEISINVALID = 'InvalidParameter.ZipCodeIsInvalid'
 
+# 表单参数取值错误。
+INVALIDPARAMETERVALUE_INVALIDPARAMETERFORMAT = 'InvalidParameterValue.InvalidParameterFormat'
+
 # 超过配额限制。
 LIMITEXCEEDED = 'LimitExceeded'
 
@@ -188,6 +233,9 @@ LIMITEXCEEDED_REQUESTLIMIT = 'LimitExceeded.RequestLimit'
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
+# 未定义路由。
+MISSINGPARAMETER_ACTIONNOTFOUND = 'MissingParameter.ActionNotFound'
+
 # 域名不能为空。
 MISSINGPARAMETER_DOMAINISEMPTY = 'MissingParameter.DomainIsEmpty'
 
